/*This file is part of SoftSERVE.
 *
 *   SoftSERVE is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   SoftSERVE is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with SoftSERVE.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCAi for the 5D integration at all eps-orders of the Rest-CA structure. 
 * Example: CAI5EM1y ('CA' structure, 'I'ntegration over '5' dimensions, at 'E'ps to the 'M'inus '1'st order, with the only missing integration over 'y' or its rescaled version) 
 * contains various differences of logs of FXi functions evaluated at x=0, i.e. with only the delta arising from the y/x +-distribution, multiplied 
 * with the correct XCA functions to arrive at eps^-1. 
 */

#include <5IntCA.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorCA.h>
#include <Input_Common.h>


//missing integration y (x after rescaling)

double CAI5EM1y(double w,double s6,double z,double s5,double c) {
	return -2*pow(c,-1)*pow(mexp,-1)*pow(n,-1)*pow(s5,-1)*pow(z,-1)*(XCA0(w,s6,0,0,0) - XCA0(w,s6,0,0,c) - XCA0(w,s6,0,z,0) + XCA0(w,s6,0,z,c) - XCA0(w,s6,s5,0,0) + XCA0(w,s6,s5,0,c) + XCA0(w,s6,s5,z,0) -
		     XCA0(w,s6,s5,z,c));
}

double CAI5E0y(double w,double s6,double z,double s5,double c) {
	return 2*pow(mexp,-1)*pow(n,-1)*((-4*log(c) - 2*log(s5) - 4*log(z))*pow(z,-1)*(-(pow(s5,-1)*(-(pow(c,-1)*(-XCA0(w,s6,0,0,0) + XCA0(w,s6,0,0,c))) + pow(c,-1)*(-XCA0(w,s6,s5,0,0) + XCA0(w,s6,s5,0,c)))) + 
        pow(s5,-1)*(-(pow(c,-1)*(-XCA0(w,s6,0,z,0) + XCA0(w,s6,0,z,c))) + pow(c,-1)*(-XCA0(w,s6,s5,z,0) + XCA0(w,s6,s5,z,c)))) + 
     pow(c,-1)*(-(pow(z,-1)*(-(pow(s5,-1)*(-(log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA0(w,s6,0,0,0)) + 
                  log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA0(w,s6,s5,0,0))) + 
             pow(s5,-1)*(-(log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))*XCA0(w,s6,0,z,0)) + 
                log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)*FA2(v(w),tl(s6),0,t5(s5),u(z),0)*FB1(v(w),tl(s6),0,t5(s5),u(z),0)*FB2(v(w),tl(s6),0,t5(s5),u(z),0))*XCA0(w,s6,s5,z,0)))) + 
        pow(z,-1)*(-(pow(s5,-1)*(-(log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XCA0(w,s6,0,0,c)) + 
                log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA0(w,s6,s5,0,c))) + 
           pow(s5,-1)*(-(log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c)))*XCA0(w,s6,0,z,c)) + 
              log(FA1(v(w),tl(s6),0,t5(s5),u(z),b(c))*FA2(v(w),tl(s6),0,t5(s5),u(z),b(c))*FB1(v(w),tl(s6),0,t5(s5),u(z),b(c))*FB2(v(w),tl(s6),0,t5(s5),u(z),b(c)))*XCA0(w,s6,s5,z,c)))) + 
     pow(z,-1)*(-(pow(s5,-1)*(-(pow(c,-1)*(-XCA1(w,s6,0,0,0) + XCA1(w,s6,0,0,c))) + pow(c,-1)*(-XCA1(w,s6,s5,0,0) + XCA1(w,s6,s5,0,c)))) + 
        pow(s5,-1)*(-(pow(c,-1)*(-XCA1(w,s6,0,z,0) + XCA1(w,s6,0,z,c))) + pow(c,-1)*(-XCA1(w,s6,s5,z,0) + XCA1(w,s6,s5,z,c)))));
}

//missing integration t5 (s5 after rescaling)

double CAI5EM1t(double w,double s6,double x,double z,double c) {
	return 0;
}

double CAI5E0t(double w,double s6,double x,double z,double c) {
	return -2*pow(x,-1)*(-(pow(z,-1)*(-(pow(c,-1)*(-(log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA0(w,s6,0,0,0)) + 
               log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XCA0(w,s6,0,0,c))) + 
          pow(c,-1)*(-(log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))*XCA0(w,s6,0,z,0)) + 
             log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c)))*XCA0(w,s6,0,z,c)))) + 
     pow(z,-1)*(-(pow(c,-1)*(-(log(FA1(v(w),tl(s6),y(x),0,0,0)*FA2(v(w),tl(s6),y(x),0,0,0)*FB1(v(w),tl(s6),y(x),0,0,0)*FB2(v(w),tl(s6),y(x),0,0,0))*XCA0(w,s6,0,0,0)) + 
             log(FA1(v(w),tl(s6),y(x),0,0,b(c))*FA2(v(w),tl(s6),y(x),0,0,b(c))*FB1(v(w),tl(s6),y(x),0,0,b(c))*FB2(v(w),tl(s6),y(x),0,0,b(c)))*XCA0(w,s6,0,0,c))) + 
        pow(c,-1)*(-(log(FA1(v(w),tl(s6),y(x),0,u(z),0)*FA2(v(w),tl(s6),y(x),0,u(z),0)*FB1(v(w),tl(s6),y(x),0,u(z),0)*FB2(v(w),tl(s6),y(x),0,u(z),0))*XCA0(w,s6,0,z,0)) + 
           log(FA1(v(w),tl(s6),y(x),0,u(z),b(c))*FA2(v(w),tl(s6),y(x),0,u(z),b(c))*FB1(v(w),tl(s6),y(x),0,u(z),b(c))*FB2(v(w),tl(s6),y(x),0,u(z),b(c)))*XCA0(w,s6,0,z,c))));
}

//missing integration u (z after rescaling)

double CAI5EM1u(double w,double s6,double x,double s5,double c) {
	return 0;
}

double CAI5E0u(double w,double s6,double x,double s5,double c) {
	return -(pow(x,-1)*(-(pow(s5,-1)*(-(pow(c,-1)*(-(log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA0(w,s6,0,0,0)) + 
                 log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XCA0(w,s6,0,0,c))) + 
            pow(c,-1)*(-(log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA0(w,s6,s5,0,0)) + 
               log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA0(w,s6,s5,0,c)))) + 
       pow(s5,-1)*(-(pow(c,-1)*(-(log(FA1(v(w),tl(s6),y(x),0,0,0)*FA2(v(w),tl(s6),y(x),0,0,0)*FB1(v(w),tl(s6),y(x),0,0,0)*FB2(v(w),tl(s6),y(x),0,0,0))*XCA0(w,s6,0,0,0)) + 
               log(FA1(v(w),tl(s6),y(x),0,0,b(c))*FA2(v(w),tl(s6),y(x),0,0,b(c))*FB1(v(w),tl(s6),y(x),0,0,b(c))*FB2(v(w),tl(s6),y(x),0,0,b(c)))*XCA0(w,s6,0,0,c))) + 
          pow(c,-1)*(-(log(FA1(v(w),tl(s6),y(x),t5(s5),0,0)*FA2(v(w),tl(s6),y(x),t5(s5),0,0)*FB1(v(w),tl(s6),y(x),t5(s5),0,0)*FB2(v(w),tl(s6),y(x),t5(s5),0,0))*XCA0(w,s6,s5,0,0)) + 
             log(FA1(v(w),tl(s6),y(x),t5(s5),0,b(c))*FA2(v(w),tl(s6),y(x),t5(s5),0,b(c))*FB1(v(w),tl(s6),y(x),t5(s5),0,b(c))*FB2(v(w),tl(s6),y(x),t5(s5),0,b(c)))*XCA0(w,s6,s5,0,c)))));
}

//missing integration b (c after rescaling)

double CAI5EM1b(double w,double s6,double x,double z,double s5) {
	return 0;
}

double CAI5E0b(double w,double s6,double x,double z,double s5) {
	return -(pow(x,-1)*(-(pow(z,-1)*(-(pow(s5,-1)*(-(log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA0(w,s6,0,0,0)) + 
                 log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA0(w,s6,s5,0,0))) + 
            pow(s5,-1)*(-(log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))*XCA0(w,s6,0,z,0)) + 
               log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)*FA2(v(w),tl(s6),0,t5(s5),u(z),0)*FB1(v(w),tl(s6),0,t5(s5),u(z),0)*FB2(v(w),tl(s6),0,t5(s5),u(z),0))*XCA0(w,s6,s5,z,0)))) + 
       pow(z,-1)*(-(pow(s5,-1)*(-(log(FA1(v(w),tl(s6),y(x),0,0,0)*FA2(v(w),tl(s6),y(x),0,0,0)*FB1(v(w),tl(s6),y(x),0,0,0)*FB2(v(w),tl(s6),y(x),0,0,0))*XCA0(w,s6,0,0,0)) + 
               log(FA1(v(w),tl(s6),y(x),t5(s5),0,0)*FA2(v(w),tl(s6),y(x),t5(s5),0,0)*FB1(v(w),tl(s6),y(x),t5(s5),0,0)*FB2(v(w),tl(s6),y(x),t5(s5),0,0))*XCA0(w,s6,s5,0,0))) + 
          pow(s5,-1)*(-(log(FA1(v(w),tl(s6),y(x),0,u(z),0)*FA2(v(w),tl(s6),y(x),0,u(z),0)*FB1(v(w),tl(s6),y(x),0,u(z),0)*FB2(v(w),tl(s6),y(x),0,u(z),0))*XCA0(w,s6,0,z,0)) + 
             log(FA1(v(w),tl(s6),y(x),t5(s5),u(z),0)*FA2(v(w),tl(s6),y(x),t5(s5),u(z),0)*FB1(v(w),tl(s6),y(x),t5(s5),u(z),0)*FB2(v(w),tl(s6),y(x),t5(s5),u(z),0))*XCA0(w,s6,s5,z,0)))));
}
