/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XPNFij for the 3D integration at all eps-orders and the alpha^-1 order of the pseudo-nf structure. 
 * Example: PNfI3EP1AM1 ('P'seudo-'Nf' structure, 'I'ntegration over '3' dimensions, at 'E'ps to the 'P'lus '1'st and 'A'lpha to the 'M'inus '1'st order) 
 * contains logs of FXi functions evaluated at z=0,x=0,s5=0, i.e. with the deltas from all +-distributions, multiplied 
 * with the correct XPNF functions to arrive at eps^1 alpha^-1. 
 */

#include <Auxiliaries.h>
#include <3IntPNFAM1.h>
#include <cmath>
#include <XFactorPNf.h>
#include <Input_Common.h>

double PNfI3EM2AM1(double w,double s6,double c) {
	return XPNF00(w,s6,0,0,c)/2.;
}

double PNfI3EM1AM1(double w,double s6,double c) {
	return (log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XPNF00(w,s6,0,0,c) + XPNF01(w,s6,0,0,c))/2.;
}

double PNfI3E0AM1(double w,double s6,double c) {
	return (2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*
      XPNF00(w,s6,0,0,c) + log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XPNF01(w,s6,0,0,c) + XPNF02(w,s6,0,0,c))/2.;
}

double PNfI3EP1AM1(double w,double s6,double c) {
	return (8*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),3))*
      XPNF00(w,s6,0,0,c) + 3*(2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + 
           pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XPNF01(w,s6,0,0,c) + log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*
         XPNF02(w,s6,0,0,c) + XPNF03(w,s6,0,0,c)))/6.;
}


