/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XNfij for the 3D integration at all eps-orders and the alpha^-1 order of the nf structure. 
 * Example: NfI3EP1AM1 ('Nf' structure, 'I'ntegration over '3' dimensions, at 'E'ps to the 'Plus '1'st and 'A'lpha to the 'M'inus '1'st order) 
 * contains logs of FXi functions evaluated at z=0,x=0,s5=0, i.e. with the deltas from all +-distributions, multiplied 
 * with the correct XNf functions to arrive at eps^1 alpha^-1. 
 */

#include <3IntNFAM1.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorNf.h>
#include <Input_Common.h>

double NfI3EM2AM1(double w,double s6,double c) {
	return XNf0(w,s6,0,0,c);
}

double NfI3EM1AM1(double w,double s6,double c) {
	return (log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XNf0(w,s6,0,0,c) + XNf1(w,s6,0,0,c);
}

double NfI3E0AM1(double w,double s6,double c) {
	return 2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XNf0(w,s6,0,0,c) + 
   (log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XNf1(w,s6,0,0,c) + XNf2(w,s6,0,0,c);
}

double NfI3EP1AM1(double w,double s6,double c) {
	return (8*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),3))*XNf0(w,s6,0,0,c))/3. + 
   2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XNf1(w,s6,0,0,c) + 
   (log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XNf2(w,s6,0,0,c) + XNf3(w,s6,0,0,c);
}
