/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XPNfij for the 3D integration at all eps-orders and the alpha^0 order of the pseudo-nf structure. 
 * Example: PNfI3EM2 ('P'seudo-'Nf' structure, 'I'ntegration over '3' dimensions, at 'E'ps to the 'M'inus '2'nd and alpha^0 order) 
 * contains logs of FXi functions evaluated at z=0,x=0,s5=0, i.e. with the deltas from all +-distributions, multiplied 
 * with the correct XPNf functions to arrive at eps^-2 alpha^0. 
 */

#include <3IntPNF.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorPNf.h>
#include <Input_Common.h>

double PNfI3EM2(double w,double s6,double c) {
	return ((log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XPNf0(w,s6,0,0,c))/4.;
}

double PNfI3EM1(double w,double s6,double c) {
	return (pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XPNf0(w,s6,0,0,c) + 
   ((log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XPNf1(w,s6,0,0,c))/4.;
}

double PNfI3E0(double w,double s6,double c) {
	return 2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),3))*XPNf0(w,s6,0,0,c) + 
   (pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XPNf1(w,s6,0,0,c) + 
   ((log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XPNf2(w,s6,0,0,c))/4.;
}


