/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCAij for the 4D integration at all eps-orders and the alpha^0 order of the Rest-CA structure. 
 * Example: CAI4EM1sz ('CA' structure, 'I'ntegration over '4' dimensions, at 'E'ps to the 'M'inus '1'st and alpha^0 order, third and fourth integration over 's'5 and 'z') 
 * contains various differences of logs of FXi functions evaluated at c=0,x=0, i.e. with deltas from all +-distributions except the t5/s5 and u/z ones, multiplied 
 * with the correct XCA functions to arrive at eps^-1 alpha^0. 
 */

#include <4IntCA.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorCA.h>
#include <Input_Common.h>

//third and forth integration over x, s5

double CAI4EM2xs(double w,double s6,double x,double s5) {
	return 0;
}

double CAI4EM1xs(double w,double s6,double x,double s5) {
	return (mexp*pow(s5,-1)*pow(x,-1)*(log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)*pow(FA1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FA2(v(w),tl(s6),y(x),0,0,0),-1)*
          pow(FB1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB2(v(w),tl(s6),y(x),0,0,0),-1))*XCA0(w,s6,0,0,0) + 
       log(FA1(v(w),tl(s6),y(x),t5(s5),0,0)*FA2(v(w),tl(s6),y(x),t5(s5),0,0)*FB1(v(w),tl(s6),y(x),t5(s5),0,0)*FB2(v(w),tl(s6),y(x),t5(s5),0,0)*pow(FA1(v(w),tl(s6),0,t5(s5),0,0),-1)*
          pow(FA2(v(w),tl(s6),0,t5(s5),0,0),-1)*pow(FB1(v(w),tl(s6),0,t5(s5),0,0),-1)*pow(FB2(v(w),tl(s6),0,t5(s5),0,0),-1))*XCA0(w,s6,s5,0,0)))/4.;
}

double CAI4E0xs(double w,double s6,double x,double s5) {
	return (mexp*pow(s5,-1)*pow(x,-1)*(-2*(log(s5)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)*pow(FA1(v(w),tl(s6),y(x),0,0,0),-1)*
             pow(FA2(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB2(v(w),tl(s6),y(x),0,0,0),-1)) - pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA1(v(w),tl(s6),y(x),0,0,0)),2) - 
          pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),y(x),0,0,0)),2) - pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),y(x),0,0,0)),2) - pow(log(FB2(v(w),tl(s6),0,0,0,0)),2) + 
          pow(log(FB2(v(w),tl(s6),y(x),0,0,0)),2))*XCA0(w,s6,0,0,0) + 2*(log(s5)*log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0)*
             pow(FA1(v(w),tl(s6),y(x),t5(s5),0,0),-1)*pow(FA2(v(w),tl(s6),y(x),t5(s5),0,0),-1)*pow(FB1(v(w),tl(s6),y(x),t5(s5),0,0),-1)*pow(FB2(v(w),tl(s6),y(x),t5(s5),0,0),-1)) - 
          pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA1(v(w),tl(s6),y(x),t5(s5),0,0)),2) - pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA2(v(w),tl(s6),y(x),t5(s5),0,0)),2) - 
          pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB1(v(w),tl(s6),y(x),t5(s5),0,0)),2) - pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB2(v(w),tl(s6),y(x),t5(s5),0,0)),2))*XCA0(w,s6,s5,0,0) + 
       log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)*pow(FA1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FA2(v(w),tl(s6),y(x),0,0,0),-1)*
          pow(FB1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB2(v(w),tl(s6),y(x),0,0,0),-1))*XCA1(w,s6,0,0,0) + 
       log(FA1(v(w),tl(s6),y(x),t5(s5),0,0)*FA2(v(w),tl(s6),y(x),t5(s5),0,0)*FB1(v(w),tl(s6),y(x),t5(s5),0,0)*FB2(v(w),tl(s6),y(x),t5(s5),0,0)*pow(FA1(v(w),tl(s6),0,t5(s5),0,0),-1)*
          pow(FA2(v(w),tl(s6),0,t5(s5),0,0),-1)*pow(FB1(v(w),tl(s6),0,t5(s5),0,0),-1)*pow(FB2(v(w),tl(s6),0,t5(s5),0,0),-1))*XCA1(w,s6,s5,0,0)))/4.;
}

//third and forth integration over x, z

double CAI4EM2xz(double w,double s6,double x,double z) {
	return 0;
}

double CAI4EM1xz(double w,double s6,double x,double z) {
	return (mexp*pow(x,-1)*pow(z,-1)*(log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)*pow(FA1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FA2(v(w),tl(s6),y(x),0,0,0),-1)*
          pow(FB1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB2(v(w),tl(s6),y(x),0,0,0),-1))*XCA0(w,s6,0,0,0) + 
       log(FA1(v(w),tl(s6),y(x),0,u(z),0)*FA2(v(w),tl(s6),y(x),0,u(z),0)*FB1(v(w),tl(s6),y(x),0,u(z),0)*FB2(v(w),tl(s6),y(x),0,u(z),0)*pow(FA1(v(w),tl(s6),0,0,u(z),0),-1)*pow(FA2(v(w),tl(s6),0,0,u(z),0),-1)*
          pow(FB1(v(w),tl(s6),0,0,u(z),0),-1)*pow(FB2(v(w),tl(s6),0,0,u(z),0),-1))*XCA0(w,s6,0,z,0)))/2.;
}

double CAI4E0xz(double w,double s6,double x,double z) {
	return (mexp*pow(x,-1)*pow(z,-1)*(-2*(2*log(z)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)*pow(FA1(v(w),tl(s6),y(x),0,0,0),-1)*
             pow(FA2(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB2(v(w),tl(s6),y(x),0,0,0),-1)) - pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA1(v(w),tl(s6),y(x),0,0,0)),2) - 
          pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),y(x),0,0,0)),2) - pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),y(x),0,0,0)),2) - pow(log(FB2(v(w),tl(s6),0,0,0,0)),2) + 
          pow(log(FB2(v(w),tl(s6),y(x),0,0,0)),2))*XCA0(w,s6,0,0,0) + 2*(2*log(z)*log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0)*
             pow(FA1(v(w),tl(s6),y(x),0,u(z),0),-1)*pow(FA2(v(w),tl(s6),y(x),0,u(z),0),-1)*pow(FB1(v(w),tl(s6),y(x),0,u(z),0),-1)*pow(FB2(v(w),tl(s6),y(x),0,u(z),0),-1)) - pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + 
          pow(log(FA1(v(w),tl(s6),y(x),0,u(z),0)),2) - pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),y(x),0,u(z),0)),2) - pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) + 
          pow(log(FB1(v(w),tl(s6),y(x),0,u(z),0)),2) - pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB2(v(w),tl(s6),y(x),0,u(z),0)),2))*XCA0(w,s6,0,z,0) + 
       log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)*pow(FA1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FA2(v(w),tl(s6),y(x),0,0,0),-1)*
          pow(FB1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB2(v(w),tl(s6),y(x),0,0,0),-1))*XCA1(w,s6,0,0,0) + 
       log(FA1(v(w),tl(s6),y(x),0,u(z),0)*FA2(v(w),tl(s6),y(x),0,u(z),0)*FB1(v(w),tl(s6),y(x),0,u(z),0)*FB2(v(w),tl(s6),y(x),0,u(z),0)*pow(FA1(v(w),tl(s6),0,0,u(z),0),-1)*pow(FA2(v(w),tl(s6),0,0,u(z),0),-1)*
          pow(FB1(v(w),tl(s6),0,0,u(z),0),-1)*pow(FB2(v(w),tl(s6),0,0,u(z),0),-1))*XCA1(w,s6,0,z,0)))/2.;
}


//third and forth integration over x, c

double CAI4EM2xc(double w,double s6,double x,double c) {
	return 0;
}

double CAI4EM1xc(double w,double s6,double x,double c) {
	return (mexp*pow(c,-1)*pow(x,-1)*(log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)*pow(FA1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FA2(v(w),tl(s6),y(x),0,0,0),-1)*
          pow(FB1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB2(v(w),tl(s6),y(x),0,0,0),-1))*XCA0(w,s6,0,0,0) + 
       log(FA1(v(w),tl(s6),y(x),0,0,b(c))*FA2(v(w),tl(s6),y(x),0,0,b(c))*FB1(v(w),tl(s6),y(x),0,0,b(c))*FB2(v(w),tl(s6),y(x),0,0,b(c))*pow(FA1(v(w),tl(s6),0,0,0,b(c)),-1)*pow(FA2(v(w),tl(s6),0,0,0,b(c)),-1)*
          pow(FB1(v(w),tl(s6),0,0,0,b(c)),-1)*pow(FB2(v(w),tl(s6),0,0,0,b(c)),-1))*XCA0(w,s6,0,0,c)))/2.;
}

double CAI4E0xc(double w,double s6,double x,double c) {
	return (mexp*pow(c,-1)*pow(x,-1)*(-2*(2*log(c)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)*pow(FA1(v(w),tl(s6),y(x),0,0,0),-1)*
             pow(FA2(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB2(v(w),tl(s6),y(x),0,0,0),-1)) - pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA1(v(w),tl(s6),y(x),0,0,0)),2) - 
          pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),y(x),0,0,0)),2) - pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),y(x),0,0,0)),2) - pow(log(FB2(v(w),tl(s6),0,0,0,0)),2) + 
          pow(log(FB2(v(w),tl(s6),y(x),0,0,0)),2))*XCA0(w,s6,0,0,0) + 2*(2*log(c)*log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))*
             pow(FA1(v(w),tl(s6),y(x),0,0,b(c)),-1)*pow(FA2(v(w),tl(s6),y(x),0,0,b(c)),-1)*pow(FB1(v(w),tl(s6),y(x),0,0,b(c)),-1)*pow(FB2(v(w),tl(s6),y(x),0,0,b(c)),-1)) - pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + 
          pow(log(FA1(v(w),tl(s6),y(x),0,0,b(c))),2) - pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),y(x),0,0,b(c))),2) - pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + 
          pow(log(FB1(v(w),tl(s6),y(x),0,0,b(c))),2) - pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),y(x),0,0,b(c))),2))*XCA0(w,s6,0,0,c) + 
       log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0)*pow(FA1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FA2(v(w),tl(s6),y(x),0,0,0),-1)*
          pow(FB1(v(w),tl(s6),y(x),0,0,0),-1)*pow(FB2(v(w),tl(s6),y(x),0,0,0),-1))*XCA1(w,s6,0,0,0) + 
       log(FA1(v(w),tl(s6),y(x),0,0,b(c))*FA2(v(w),tl(s6),y(x),0,0,b(c))*FB1(v(w),tl(s6),y(x),0,0,b(c))*FB2(v(w),tl(s6),y(x),0,0,b(c))*pow(FA1(v(w),tl(s6),0,0,0,b(c)),-1)*pow(FA2(v(w),tl(s6),0,0,0,b(c)),-1)*
          pow(FB1(v(w),tl(s6),0,0,0,b(c)),-1)*pow(FB2(v(w),tl(s6),0,0,0,b(c)),-1))*XCA1(w,s6,0,0,c)))/2.;
}


//third and forth integration over s5, z

double CAI4EM2sz(double w,double s6,double s5,double z) {
	return 0.;
}

double CAI4EM1sz(double w,double s6,double s5,double z) {
	return (pow(s5,-1)*pow(z,-1)*(-(log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA0(w,s6,0,0,0)) + 
       log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))*XCA0(w,s6,0,z,0) + 
       log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA0(w,s6,s5,0,0) - 
       log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)*FA2(v(w),tl(s6),0,t5(s5),u(z),0)*FB1(v(w),tl(s6),0,t5(s5),u(z),0)*FB2(v(w),tl(s6),0,t5(s5),u(z),0))*XCA0(w,s6,s5,z,0)))/2.;
}

double CAI4E0sz(double w,double s6,double s5,double z) {
	return (pow(s5,-1)*pow(z,-1)*(2*log(s5)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA0(w,s6,0,0,0) + 
       4*log(z)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA0(w,s6,0,0,0) - 
       4*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA0(w,s6,0,0,0) - 
       2*log(s5)*log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))*XCA0(w,s6,0,z,0) - 
       4*log(z)*log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))*XCA0(w,s6,0,z,0) + 
       4*(pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2))*XCA0(w,s6,0,z,0) - 
       2*log(s5)*log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA0(w,s6,s5,0,0) - 
       4*log(z)*log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA0(w,s6,s5,0,0) + 
       4*(pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2))*XCA0(w,s6,s5,0,0) + 
       2*log(s5)*log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)*FA2(v(w),tl(s6),0,t5(s5),u(z),0)*FB1(v(w),tl(s6),0,t5(s5),u(z),0)*FB2(v(w),tl(s6),0,t5(s5),u(z),0))*XCA0(w,s6,s5,z,0) + 
       4*log(z)*log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)*FA2(v(w),tl(s6),0,t5(s5),u(z),0)*FB1(v(w),tl(s6),0,t5(s5),u(z),0)*FB2(v(w),tl(s6),0,t5(s5),u(z),0))*XCA0(w,s6,s5,z,0) - 
       4*(pow(log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),u(z),0)),2) + pow(log(FB2(v(w),tl(s6),0,t5(s5),u(z),0)),2))*
        XCA0(w,s6,s5,z,0) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA1(w,s6,0,0,0) + 
       log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))*XCA1(w,s6,0,z,0) + 
       log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA1(w,s6,s5,0,0) - 
       log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)*FA2(v(w),tl(s6),0,t5(s5),u(z),0)*FB1(v(w),tl(s6),0,t5(s5),u(z),0)*FB2(v(w),tl(s6),0,t5(s5),u(z),0))*XCA1(w,s6,s5,z,0)))/2.;
}


//third and forth integration over s5, c

double CAI4EM2sc(double w,double s6,double s5,double c) {
	return 0;
}

double CAI4EM1sc(double w,double s6,double s5,double c) {
	return (pow(c,-1)*pow(s5,-1)*(-(log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA0(w,s6,0,0,0)) + 
       log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XCA0(w,s6,0,0,c) + 
       log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA0(w,s6,s5,0,0) - 
       log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA0(w,s6,s5,0,c)))/2.;
}

double CAI4E0sc(double w,double s6,double s5,double c) {
	return (pow(c,-1)*pow(s5,-1)*(4*log(c)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA0(w,s6,0,0,0) + 
       2*log(s5)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA0(w,s6,0,0,0) - 
       4*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA0(w,s6,0,0,0) - 
       4*log(c)*log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XCA0(w,s6,0,0,c) - 
       2*log(s5)*log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XCA0(w,s6,0,0,c) + 
       4*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XCA0(w,s6,0,0,c) - 
       4*log(c)*log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA0(w,s6,s5,0,0) - 
       2*log(s5)*log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA0(w,s6,s5,0,0) + 
       4*(pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2))*XCA0(w,s6,s5,0,0) + 
       4*log(c)*log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA0(w,s6,s5,0,c) + 
       2*log(s5)*log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA0(w,s6,s5,0,c) - 
       4*(pow(log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,b(c))),2))*
        XCA0(w,s6,s5,0,c) - log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA1(w,s6,0,0,0) + 
       log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XCA1(w,s6,0,0,c) + 
       log(FA1(v(w),tl(s6),0,t5(s5),0,0)*FA2(v(w),tl(s6),0,t5(s5),0,0)*FB1(v(w),tl(s6),0,t5(s5),0,0)*FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA1(w,s6,s5,0,0) - 
       log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA1(w,s6,s5,0,c)))/2.;
}


//third and forth integration over z, c

double CAI4EM2zc(double w,double s6,double z,double c) {
	return 0;
}

double CAI4EM1zc(double w,double s6,double z,double c) {
	return pow(c,-1)*pow(z,-1)*(-(log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA0(w,s6,0,0,0)) + 
     log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XCA0(w,s6,0,0,c) + 
     log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))*XCA0(w,s6,0,z,0) - 
     log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c)))*XCA0(w,s6,0,z,c));
}

double CAI4E0zc(double w,double s6,double z,double c) {
	return pow(c,-1)*pow(z,-1)*(4*log(c*z)*log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA0(w,s6,0,0,0) - 
     4*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA0(w,s6,0,0,0) - 
     4*log(c*z)*log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XCA0(w,s6,0,0,c) + 
     4*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XCA0(w,s6,0,0,c) - 
     4*log(c*z)*log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))*XCA0(w,s6,0,z,0) + 
     4*(pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2))*XCA0(w,s6,0,z,0) + 
     4*log(c*z)*log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c)))*XCA0(w,s6,0,z,c) - 
     4*(pow(log(FA1(v(w),tl(s6),0,0,u(z),b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,u(z),b(c))),2))*XCA0(w,s6,0,z,c) - 
     log(FA1(v(w),tl(s6),0,0,0,0)*FA2(v(w),tl(s6),0,0,0,0)*FB1(v(w),tl(s6),0,0,0,0)*FB2(v(w),tl(s6),0,0,0,0))*XCA1(w,s6,0,0,0) + 
     log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XCA1(w,s6,0,0,c) + 
     log(FA1(v(w),tl(s6),0,0,u(z),0)*FA2(v(w),tl(s6),0,0,u(z),0)*FB1(v(w),tl(s6),0,0,u(z),0)*FB2(v(w),tl(s6),0,0,u(z),0))*XCA1(w,s6,0,z,0) - 
     log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c)))*XCA1(w,s6,0,z,c));
}
