/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XNfij for the 5D integration at all eps-orders and the alpha^0 order of the nf structure. 
 * Example: NfI5E0x ('Nf' structure, 'I'ntegration over '5' dimensions, at 'E'ps to the '0'th and alpha^0 order, only missing integration over 'x') 
 * contains logs of FXi functions evaluated at x=0, i.e. with only the delta from the y/x +-distribution, multiplied 
 * with the correct XNf functions to arrive at eps^0 alpha^0. 
 */

#include <5IntNF.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorNf.h>
#include <Input_Common.h>

/*
 * leading terms (1/eps) vanish, since that means integrating x
 * (otherwise there'd be an alpha), which has a vanishing
 * leading order in its +-dist
 */

// additional integrations run over x, s5

double NfI5E0z(double w,double s6,double x,double s5,double c) {
	return mexp*pow(s5,-1)*pow(x,-1)*(log(FA1(v(w),tl(s6),y(x),0,0,b(c))*FA2(v(w),tl(s6),y(x),0,0,b(c))*FB1(v(w),tl(s6),y(x),0,0,b(c))*FB2(v(w),tl(s6),y(x),0,0,b(c))*pow(FA1(v(w),tl(s6),0,0,0,b(c)),-1)*
        pow(FA2(v(w),tl(s6),0,0,0,b(c)),-1)*pow(FB1(v(w),tl(s6),0,0,0,b(c)),-1)*pow(FB2(v(w),tl(s6),0,0,0,b(c)),-1))*XNf0(w,s6,0,0,c) + 
     log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c))*pow(FA1(v(w),tl(s6),y(x),t5(s5),0,b(c)),-1)*
        pow(FA2(v(w),tl(s6),y(x),t5(s5),0,b(c)),-1)*pow(FB1(v(w),tl(s6),y(x),t5(s5),0,b(c)),-1)*pow(FB2(v(w),tl(s6),y(x),t5(s5),0,b(c)),-1))*XNf0(w,s6,s5,0,c));
}

// additional integrations run over x, z

double NfI5E0s(double w,double s6,double x,double z,double c) {
	return -2*mexp*pow(x,-1)*pow(z,-1)*(log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))*pow(FA1(v(w),tl(s6),y(x),0,0,b(c)),-1)*
        pow(FA2(v(w),tl(s6),y(x),0,0,b(c)),-1)*pow(FB1(v(w),tl(s6),y(x),0,0,b(c)),-1)*pow(FB2(v(w),tl(s6),y(x),0,0,b(c)),-1))*XNf0(w,s6,0,0,c) + 
     log(FA1(v(w),tl(s6),y(x),0,u(z),b(c))*FA2(v(w),tl(s6),y(x),0,u(z),b(c))*FB1(v(w),tl(s6),y(x),0,u(z),b(c))*FB2(v(w),tl(s6),y(x),0,u(z),b(c))*pow(FA1(v(w),tl(s6),0,0,u(z),b(c)),-1)*
        pow(FA2(v(w),tl(s6),0,0,u(z),b(c)),-1)*pow(FB1(v(w),tl(s6),0,0,u(z),b(c)),-1)*pow(FB2(v(w),tl(s6),0,0,u(z),b(c)),-1))*XNf0(w,s6,0,z,c));
}

// additional integrations run over s5, z

double NfI5E0x(double w,double s6,double s5,double z,double c) {
	return pow(s5,-1)*pow(z,-1)*(2*log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XNf0(w,s6,0,0,c) - 
     2*log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c)))*XNf0(w,s6,0,z,c) - 
     2*log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XNf0(w,s6,s5,0,c) + 
     2*log(FA1(v(w),tl(s6),0,t5(s5),u(z),b(c))*FA2(v(w),tl(s6),0,t5(s5),u(z),b(c))*FB1(v(w),tl(s6),0,t5(s5),u(z),b(c))*FB2(v(w),tl(s6),0,t5(s5),u(z),b(c)))*XNf0(w,s6,s5,z,c));
}
