/*
 * This file contains all prefactors that mix the various eps-orders of the integrations after the integrations are performed 
 * to arrive at the eps-orders of the full bare soft function. The notation is such that PreXXij is the alpha^i eps^j order of the
 * prefactor for the XX colour structure, with XX standing in for Real-CA (CA), Pseudo-nf (PNF), nf (NF), 1-loop (OL) and real-
 * virtual interference (RV). For the latter two the notation makes alpha and eps powers explicit, i.e. PreOLA0EM1 is 
 * the alpha^0 eps^-1 power of the one-loop prefactor, A and E are omitted for CA, PNF and NF
 */

#include <Auxiliaries.h>
#include <Prefactors.h>
#include <Input_Common.h>
#include <cmath>
using namespace std;

double PreNF00=-32768*pow(Pi,-2);
double PreNF01=196608*log(2)*pow(Pi,-2);
double PreNF02=-32768*pow(Pi,-2)*(pow(Pi,2) + 18*pow(log(2),2));
double PreNF03=-(-65536*pow(Pi,-2)*(-28*Zeta3 + 9*log(2)*pow(Pi,2) + 54*pow(log(2),3)))/3.;

double PreNF1M1=8192*pow(Pi,-2);
double PreNF10=-49152*log(2)*pow(Pi,-2);
double PreNF11=-(8192*(5 - 54*pow(Pi,-2)*pow(log(2),2)))/3.;
double PreNF12=-(-16384*pow(Pi,-2)*(-68*Zeta3 + 15*log(2)*pow(Pi,2) - 54*pow(log(2),3)))/3.;
double PreNF13=-(4096*pow(Pi,-2)*(391*pow(Pi,4) + 2700*pow(Pi,2)*pow(log(2),2) - 180*(136*Zeta3*log(2) + 27*pow(log(2),4))))/45.;

double PrePNF00=16384*pow(Pi,-2);
double PrePNF01=-16384*(1 + 6*log(2))*pow(Pi,-2);
double PrePNF02=16384*pow(Pi,-2)*(6*log(2) + pow(Pi,2) + 18*pow(log(2),2));
double PrePNF03=-(16384*pow(Pi,-2)*(-56*Zeta3 + 3*pow(Pi,2) + 18*log(2)*pow(Pi,2) + 54*pow(log(2),2) + 108*pow(log(2),3)))/3.;

double PrePNF1M1=-4096*pow(Pi,-2);
double PrePNF10=4096*(1 + 6*log(2))*pow(Pi,-2);
double PrePNF11=-(4096*(-5 + 18*log(2)*(1 + 3*log(2))*pow(Pi,-2)))/3.;
double PrePNF12=-(4096*pow(Pi,-2)*(5*(1 + 6*log(2))*pow(Pi,2) - 2*(68*Zeta3 + 27*pow(log(2),2) + 54*pow(log(2),3))))/3.;
double PrePNF13=-(-2048*pow(Pi,-2)*(900*log(2)*(1 + log(8))*pow(Pi,2) + 391*pow(Pi,4) - 60*(68*Zeta3 + 408*Zeta3*log(2) + 54*pow(log(2),3) + 81*pow(log(2),4))))/45.;

double PreCA00=16384*pow(Pi,-2);
double PreCA01=-98304*log(2)*pow(Pi,-2);
double PreCA02=16384*pow(Pi,-2)*(pow(Pi,2) + 18*pow(log(2),2));
double PreCA03=-(32768*pow(Pi,-2)*(-28*Zeta3 + 9*log(2)*pow(Pi,2) + 54*pow(log(2),3)))/3.;
double PreCA04=-(-8192*pow(Pi,-2)*(-672*Zeta3*log(2) + 7*pow(Pi,4) + 108*pow(Pi,2)*pow(log(2),2) + 324*pow(log(2),4)))/3.;

double PreCA1M1=-4096*pow(Pi,-2);
double PreCA10=24576*log(2)*pow(Pi,-2);
double PreCA11=-(4096*(-5 + 54*pow(Pi,-2)*pow(log(2),2)))/3.;
double PreCA12=-(8192*pow(Pi,-2)*(-68*Zeta3 + 15*log(2)*pow(Pi,2) - 54*pow(log(2),3)))/3.;
double PreCA13=-(2048*(-391*pow(Pi,2) - 2700*pow(log(2),2) + 180*pow(Pi,-2)*(136*Zeta3*log(2) + 27*pow(log(2),4))))/45.;
double PreCA14=-(4096*pow(Pi,-2)*(1173*log(2)*pow(Pi,4) + 20*pow(Pi,2)*(-214*Zeta3 + 135*pow(log(2),3)) - 108*(344*Zeta5 + 340*Zeta3*pow(log(2),2) + 27*pow(log(2),5))))/45.;


double PreOLA0EM1=-64*pow(Pi,-1);
double PreOLA0E0=256*log(2)*pow(Pi,-1);
double PreOLA0E1=-(16*pow(Pi,-1)*(96*pow(log(2),2) + pow(Pi,2)))/3.;
double PreOLA0E2=-(-64*pow(Pi,-1)*(32*pow(log(2),3) + log(2)*pow(Pi,2) - Zeta3))/3.;
double PreOLA0E3=-(2*pow(Pi,-1)*(5120*pow(log(2),4) + 320*pow(log(2),2)*pow(Pi,2) + 3*pow(Pi,4) - 640*log(2)*Zeta3))/15.;
double PreOLA1EM2=32*pow(Pi,-1);
double PreOLA1EM1=-128*log(2)*pow(Pi,-1);
double PreOLA1E0=-(56*Pi)/3. + 256*pow(log(2),2)*pow(Pi,-1);
double PreOLA1E1=-(16*pow(Pi,-1)*(64*pow(log(2),3) - 14*log(2)*pow(Pi,2) + 46*Zeta3))/3.;
double PreOLA1E2=-(pow(Pi,-1)*(-5120*pow(log(2),4) + 2240*pow(log(2),2)*pow(Pi,2) + 109*pow(Pi,4) - 14720*log(2)*Zeta3))/15.;
double PreOLA2EM3=-16*pow(Pi,-1);
double PreOLA2EM2=64*log(2)*pow(Pi,-1);
double PreOLA2EM1=4*Pi - 128*pow(log(2),2)*pow(Pi,-1);
double PreOLA2E0=-(16*pow(Pi,-1)*(-32*pow(log(2),3) + 3*log(2)*pow(Pi,2) + Zeta3))/3.;
double PreOLA2E1=-(pow(Pi,-1)*(5120*pow(log(2),4) - 960*pow(log(2),2)*pow(Pi,2) + 139*pow(Pi,4) - 640*log(2)*Zeta3))/30.;

double PreRVA0EM3=64*pow(Pi,-1);
double PreRVA0EM2=-256*log(2)*pow(Pi,-1);
double PreRVA0EM1=-(-128*pow(Pi,-1)*(12*pow(log(2),2) + pow(Pi,2)))/3.;
double PreRVA0E0=-(128*pow(Pi,-1)*(16*pow(log(2),3) + 4*log(2)*pow(Pi,2) - 25*Zeta3))/3.;
double PreRVA1EM4=-16*pow(Pi,-1);
double PreRVA1EM3=64*log(2)*pow(Pi,-1);
double PreRVA1EM2=32*pow(Pi,-1)*(-4*pow(log(2),2) + pow(Pi,2));
double PreRVA1EM1=-(32*pow(Pi,-1)*(-16*pow(log(2),3) + 12*log(2)*pow(Pi,2) - 71*Zeta3))/3.;
double PreRVA1E0=-(-16*pow(Pi,-1)*(-480*pow(log(2),4) + 720*pow(log(2),2)*pow(Pi,2) + 173*pow(Pi,4) - 8520*log(2)*Zeta3))/45.;
